# Matter and Thread could fix smart home compatibility—but don’t get excited yet
## An explainer on how Matter and Thread work and how they might actually help.
## Information:

+ Link: https://arstechnica.com/gadgets/2022/10/matter-and-thread-could-fix-smart-home-compatibility-but-dont-get-excited-yet/
+ Source: Ars Technica
+ Author: Kevin Purdy
+ Date published: 06 October 2022, 14:37
+ Date scraped: 06 October 2022, 15:00

## Article:
![Main article image](https://cdn.arstechnica.net/wp-content/uploads/2022/10/matter_home_line-760x380.jpeg)







The specification for Matter 1.0 was released on Tuesday—all [899 pages of it](https://csa-iot.org/wp-content/uploads/2022/10/22-27349-001_Matter-1.0-Core-Specification76.pdf). More importantly, smart home manufacturers and software makers can now apply for this cross-compatibility standard, have their products certified for it, and release them. What does that mean for you, the person who actually buys and deals with this stuff?


At the moment, not much. If you have smart home devices set up, some of them might start working with Matter soon, either through firmware upgrades to devices or hubs. If you're deciding whether to buy something now, you might want to wait to see if it's slated to work with Matter. The first devices with a Matter logo on the box could appear in as little as a month. Amazon, Google, Apple, and Samsung's SmartThings division have all said they're ready to update their core products with Matter compatibility when they can.


That's how Matter will arrive, but what does Matter do? You have questions, and we've got... well, not definitive answers, but information and scenarios. This is a gigantic standards working group trying to keep things moving across both the world's largest multinational companies and esoteric manufacturers of tiny circuit boards. It's a whole thing. But we'll try to answer some self-directed questions to provide some clarity.


## What is Matter? Where did it come from?


[![A standard has arrived, with actual devices and software to follow.](https://cdn.arstechnica.net/wp-content/uploads/2022/10/matter_10-1-640x320.jpeg)](https://cdn.arstechnica.net/wp-content/uploads/2022/10/matter_10-1.jpeg) / A standard has arrived, with actual devices and software to follow.CSA


Matter is maintained by the [Connectivity Standards Alliance](https://csa-iot.org/) (CSA), which was previously known as the Zigbee Alliance. Zigbee is an IEEE 802.15.43 specification for a low-power, low-data-rate mesh network that is already in use by Phillips' Hue bulbs and hubs, Amazon's Echo and Eero devices, Samsung's SmartThings, Yale smart locks, and many smaller devices. It had pretty good buy-in from manufacturers, and it proved the value of mesh networking.


Starting with that foundation, the CSA somehow built up momentum to push for something people want more than an iterative networking standard: a guarantee that if they buy, or develop, a smart home device, they won't have to figure out which corporate allegiances that device can work with. The mission was to "simplify development for manufacturers and increase compatibility for consumers," the Zigbee Alliance said, and [the new standard was called CHIP](https://arstechnica.com/gadgets/2019/12/apple-google-and-amazon-team-up-for-joint-smart-home-standard/), or "Connected Home over IP."


[Matter was delayed](https://arstechnica.com/gadgets/2021/08/apple-and-google-backed-smart-home-standard-matter-has-been-delayed/) more than once. Stacey Higginbotham, a reporter focused on IoT, [cited the COVID-19 pandemic](https://staceyoniot.com/does-it-matter-smart-home-standard-is-delayed-until-2022/) and the group's rapidly scaling size for its earliest delays. This week, with 550 members of the CSA involved in Matter standards development and a "fall 2022" release target arriving, Higginbotham [heard from insiders](https://staceyoniot.com/matter-is-now-official/) that the Matter group felt pressured to release something, even if it was scaled back from its original promises. And as you might imagine, a lot of bugs and questions come up when [more than 250](https://csa-iot.org/members/adopters/) previously siloed companies start working together on something.


## So Matter is just a new Zigbee with more corporate buy-in?


No, Matter is an interoperability standard, with many connection options available to devices. Under Matter, devices can talk to each other over standard Wi-Fi, Ethernet, Bluetooth Low-Energy, or Thread, another IEEE 802.15.43 standard (we'll get to Thread a bit later).


If you have an extensive network already set up with Zigbee or Z-Wave, it might still fit into a Matter network. Hub makers are gradually announcing firmware updates to allow for Matter compatibility, allowing them to serve as a bridge between their mesh and Matter-ready controllers and devices. Before it rebranded as the CSA, the [Zigbee Alliance announced that it would work with the Thread Group](https://www.pcworld.com/article/426754/thread-and-zigbee-snap-pieces-together-to-boost-home-iot.html) to create compatible application layers.







## What does Matter actually do for my home?


![Google plans to update much of its smart home portfolio to support Matter.](https://cdn.arstechnica.net/wp-content/uploads/2022/10/Google_Matter_TVReHXI.max-1000x1000.png)Google plans to update much of its smart home portfolio to support Matter.Google


Right now, nothing, as no devices are officially certified for Matter. But there's a future ideal.


The ideal is that however your network is set up, whatever connection your devices use, and whichever "controller" you prefer—Amazon's Alexa, Google Assistant, Apple's Home, Samsung SmartThings, or, if you're an enthusiast, Home Assistant, HomeSeer, Habitat, or other non-megacorp options—your smart home devices can at least see each other and provide some basic functionality.


If you buy a new smart lock with a Matter logo on it, you won't have to complete an arduous setup process through Google Home for your Android-using spouse, then again through HomeKit for your iPhone. Even if you later switch your whole home over to Alexa control, your Echo speakers and Alexa app should still be able to see, set up, and (ideally) operate your lock.


Matter also allows for multiple smart home controllers, not just easier switching. Every Matter-certified device must support its inclusion in at least five "fabrics," or Matter configurations. So the iPhone/Android-split couple in the previous example could each have access to a number of devices, even if some of them provide more function for one controller or the other.


## So with Matter, everything just works across all platforms, no catches?


Let's not get ahead of ourselves. There are many caveats at this 1.0 stage.


For starters, the 1.0 specification only covers relatively simple smart devices like light bulbs and switches; smart plugs and locks; basic sensors; controllers for blinds, shades, and garage doors; HVAC controllers; and, most importantly, bridges and hubs. Compatibility with items like security cameras, doorbells, speakers, and more advanced sensors and devices is due to arrive in a later specification.


Most importantly, Matter doesn't mean full compatibility across all systems. You almost certainly won't be able to access every function of an Amazon Echo speaker through Google Home, though you may be able to adjust its volume, and it can serve as a "border router" to pass along messages in a Thread network from Google devices. Similarly, a Google Nest thermostat won't provide the same experience through an Alexa or Apple home app, though those apps will likely be able to put that thermostat onto the network and perhaps turn it up or down.


## Will Matter put all of my devices on the wider Internet? Does it work offline?


Matter devices shouldn't have to be cloud-connected to work. At its core, Matter aims for the opposite. It assigns every device in your home its own IPv6 address, but those are for the local network only. Communication between devices happens on the local network and is encrypted. If your Internet connection goes down, your local Matter network should still have some basic functionality.


This also applies to devices whose [companies](https://arstechnica.com/gadgets/2022/08/smartdrys-useful-laundry-sensor-to-be-cloud-bricked-next-month/) or [servers](https://arstechnica.com/gadgets/2022/04/shameful-insteon-looks-dead-just-like-its-users-smart-homes/) disappear. If the devices are Matter-certified, they should be accessible at some level, regardless of whether their makers' servers are up and running. Whether that access is more than just an "I'm here" ping could depend on the developers.


It also depends on the controller you're using. In press coverage, and throughout Matter's press releases and documentation, a lot of attention is paid to the big four smart home platforms: Amazon Alexa, Google Home/Assistant, Apple Home/HomeKit, and Samsung/SmartThings. Those companies' phones, speakers, hubs, and other devices offer "controllers," in Matter terminology. Most of those controllers all but demand to be connected to the wider Internet, making your devices available to you remotely.


So while Matter's communication all happens on the local network—which includes devices, hubs, Thread border routers, and controllers—the controller can still call out to, and store data on, cloud servers.





## OK, let’s talk Thread. Now my stuff has to work over Thread, too?


Thread is new, and it seems like a useful upgrade to mesh technologies like Zigbee and Z-Wave, although only manufacturers have gotten some hands-on experience with it so far.


But it's not required. You could run a home with devices that only connect over Wi-Fi, Ethernet, Bluetooth, and an existing mesh network that has a Matter-compatible hub, and you'd see all the cross-compatibility benefits of Matter.


## Wasn’t Thread some kind of Nest thing Google pushed a decade ago after purchasing the company?


Good catch. [Google worked with Samsung, chip tech firm ARM, and other companies](https://gigaom.com/2014/07/15/nest-and-samsung-launch-thread-a-wireless-mesh-standard-for-the-smart-home/) in 2014 to push Thread, the tech Nest had developed for its own inter-connected devices. Google pushed updates to Nest devices in 2015 that gave them "[Nest Weave](https://arstechnica.com/gadgets/2015/10/nest-updates-cam-connects-third-party-devices-through-thread-network/)," a Thread-based way for third-party devices to interact with Nest gear. Even back then, Thread was touted as a kind of mesh network explicitly designed to let more devices work together.


Note that Google's own Thread-based "Works with Nest" ecosystem [didn't end up being so open](https://arstechnica.com/gadgets/2020/12/after-years-of-fighting-it-nest-will-work-with-samsungs-smartthings/).


## So why is Thread so important to Matter?


[![A topography showing how Thread works in a Matter-powered smart home. ](https://cdn.arstechnica.net/wp-content/uploads/2022/10/Smart-Homes-with-Matter1-640x476.png)](https://cdn.arstechnica.net/wp-content/uploads/2022/10/Smart-Homes-with-Matter1.png) / A topography showing how Thread works in a Matter-powered smart home. Thread Group


Thread is a first-class protocol in Matter for a few reasons:


* Thread takes messages moving on its mesh network and delivers them through the local network at the earliest opportunity. A Thread network doesn't have to have a strong signal to every device with which it might send or receive a message. This reduces mesh traffic, makes the mesh network more reliable, and potentially reduces the cost of mesh networking hardware ([as explained](https://news.ycombinator.com/item?id=33085312) by Home Assistant founder Paulus Schoutsen)
* Every device on the Thread network gets an IP address, making it easier for a device to broadcast data to a local network or (optional) cloud without having Wi-Fi built in.
* TCP is a required element of Thread connectivity, allowing devices to be more easily updated for security and function.
* Devices cannot join a Thread network unless they're authorized by a device already on the network (like a phone or controller), must communicate using AES-128 encryption, and don't pass or hold network keys.
* It provides self-healing capabilities with no single point of failure and spread-spectrum abilities to work around interference, like competing Wi-Fi channels.


Thread is not entirely dissimilar to Zigbee or other mesh networks: It's low-power, it's mesh, it works on the 802.11 standard, and it has roughly the same range (200–300 meters). And Thread's maximum number of devices, 250, is but a fraction of Zigbee's theoretical 65,000.


But Thread more squarely fits Matter's vision of a smart home that can be controlled by a few different people (and companies). Apple even released one of the first non-Google Thread-compatible devices, the [HomePod Mini](https://www.wired.com/review/apple-homepod-mini/), which functions as a "border router," pushing messages onto the local network for small, low-energy Thread devices and extending the network's reach.


## Is Matter open source? Is Thread?


Matter is, and it's [on GitHub](https://github.com/project-chip/connectedhomeip/tree/a01d8e491a5fa4e45afaccb2c35a136c54fbe3c3). Being a product with deep Google roots, Thread has an "open source implementation" cousin, [OpenThread](https://openthread.io/).


## Will my devices get upgraded to work with Matter?


[![This smart dimmer works on Thread, but it only connects through HomeKit, not Matter. It's complicated.](https://cdn.arstechnica.net/wp-content/uploads/2022/08/wemo_smart_dimmer-300x300.jpeg)](https://cdn.arstechnica.net/wp-content/uploads/2022/08/wemo_smart_dimmer.jpeg) / This smart dimmer works on Thread, but it only connects through HomeKit, not Matter. It's complicated.[Wemo](https://www.belkin.com/us/smart-home/wemo/na/p/p-wds070/)


It depends. Matter's SDK and license are free, provided a developer agrees to a license agreement, so if a device is capable of some level of secure networking, the costs of becoming Matter-capable are generally in person-hours and code. That said, Belkin [released a Wemo smart switch in August](https://arstechnica.com/gadgets/2022/08/wemos-confused-smart-dimmer-shows-the-standardized-smart-home-is-still-far-off/) that worked with (and in fact required) Thread networks to extend its range beyond Bluetooth. But it only works with Wemo's own app and Apple's HomeKit and will not be updated to support Matter.


Devices that already contain Zigbee internals are more likely to be able to also work over Thread, as are devices from the big companies that have already committed to Matter compatibility: Amazon, Google, Samsung, Phillips Hue (Signify), Eve, GE Lighting, LG, Schlage, Arlo, and Aqara, among others.





## What happens if my devices don’t work with Matter?


If you're using a common controller like Alexa, Home/Assistant, Home/HomeKit, or SmartThings and the devices work with them, you don't have to do anything. Your devices will still work when Matter is deployed to your controllers, hubs, and other devices.


Matter is aimed more at easing the setup and interconnection of future devices than giving existing devices new functions. But it could make some of your devices easier to set up and access with a new controller.


## I’m just glad there’s no crypto angle to any of this.


I'm sorry to inform you, but there is a bit of crypto in Matter. The Distributed Compliance Ledger (DCL) is how Matter ensures that devices joining your network really are the licensed devices they say they are. The DCL is a "cryptographically secure, distributed storage network based on blockchain technology," as chip and board maker [Espressif explains in a post about DCL](https://blog.espressif.com/matter-distributed-compliance-ledger-dcl-4013c2376e7). You shouldn't have to touch it unless you're a smart home device maker or software developer, but it's there.


## Wasn’t there an xkcd comic about this kind of “one universal standard”?


Yes. [Yes, there was](https://xkcd.com/927/). And it's certainly not an impossible scenario.


## How is this new standard better than big tech companies simply making more open, less-fragmented APIs?


[![Maybe Amazon's Astro robot will work with Matter, but that's not going to make it useful—to you or Amazon.](https://cdn.arstechnica.net/wp-content/uploads/2022/09/Amazon-Astro-640x360.jpg)](https://cdn.arstechnica.net/wp-content/uploads/2022/09/Amazon-Astro.jpg) / Maybe Amazon's Astro robot will work with Matter, but that's not going to make it useful—to you or Amazon.Amazon


That's a great question and a good point to end on. If Zigbee, Wi-Fi, and Bluetooth Low-Energy had become a *de facto* standard for smart home connections on their own and the big tech smart home controller companies had resolved to respect each others' networks and controls, Matter might not be so intriguing—or even necessary. And its scaled-back, time-crunched 1.0 release might not be disappointing to enthusiasts hoping for a total connectivity reboot.


But having the big smart home names, plus more than 550 other companies, agreeing on a basic, common connection standard is only going to become more necessary as those companies advance their own smart home schemes. Amazon is aggressively pushing Matter and Thread connectivity in its existing and future products, but it's also working to create its own "[ambient intelligence](https://www.wired.com/story/amazon-wants-to-cocoon-you-with-ambient-intelligence/)" about every one of its products in your home. Google essentially donated its Thread work to the Matter alliance, but it's working within its ecosystem to create "[intelligence clusters](https://staceyoniot.com/google-and-amazon-speak-very-differently-about-matter)." Apple and Samsung haven't presented their own nicknamed learning systems, but we assume they're in development.


If you make a garage door opener but don't want to help any of those multinational companies with their "intelligence" gathering, Matter provides, at a minimum, a way for people with those company's controllers to see, set up, and use the products, regardless of whether you've signed up with any company's device and learning platforms.


Matter, if it works, should expand your choices. You might still have to install more apps than you'd like to if you want to use the deeper features of your stuff. But you might also be able to skip the "works with" devices and find those that just work.












## Tags:


### Autogenerated tags:
[[google]] [[zigbee]] [[samsung]] [[alexa]] [[wi-fi]] [[smartthings]] [[matter?]] [[csa]] [[bluetooth]] [[low-energy]]
