# Microsoft finds vulnerabilities it says could be used to shut down power plants
## Exploitation is hard and patches are already out, but the potential risk is great.
## Information:

+ Link: https://arstechnica.com/security/2023/08/microsoft-finds-vulnerabilities-it-says-could-be-used-to-shut-down-power-plants/
+ Source: Ars Technica
+ Author: Dan Goodin
+ Date published: 11 August 2023, 20:42
+ Date scraped: 11 August 2023, 21:00

## Article:
![Main article image](https://cdn.arstechnica.net/wp-content/uploads/2021/03/industrial-control-system-760x380.jpg)







On Friday, Microsoft disclosed 15 high-severity vulnerabilities in a widely used collection of tools used to program operational devices inside industrial facilities such as plants for power generation, factory automation, energy automation, and process automation. The company warned that while exploiting the code-execution and denial-of-service vulnerabilities was difficult, it enabled threat actors to “inflict great damage on targets."


The vulnerabilities affect the CODESYS V3 software development kit. Developers inside companies such as Schneider Electric and WAGO use the platform-independent tools to develop programmable logic controllers, the toaster-sized devices that open and close valves, turn rotors, and control various other physical devices in industrial facilities worldwide. Specifically, the SDK allows developers to make PLCs compatible with [IEC 611131-3](https://webstore.iec.ch/publication/4552), an international standard that defines programming languages that are safe to use in industrial environments. Examples of devices that use CODESYS V3 include Schneider Electric’s Modicon TM251 and the WAGO PFC200.


“A DOS attack against a device using a vulnerable version of CODESYS could enable threat actors to shut down a power plant, while remote code execution could create a backdoor for devices and let attackers tamper with operations, cause a PLC to run in an unusual way, or steal critical information,” Microsoft researchers [wrote](https://www.microsoft.com/en-us/security/blog/2023/08/10/multiple-high-severity-vulnerabilities-in-codesys-v3-sdk-could-lead-to-rce-or-dos/). Friday’s advisory went on to say:



> With CODESYS being used by many vendors, one vulnerability may affect many sectors, device types, and verticals, let alone multiple vulnerabilities. All the vulnerabilities can lead to DoS and 1 RCE. While exploiting the discovered vulnerabilities requires deep knowledge of the proprietary protocol of CODESYS V3 as well as user authentication (and additional permissions are required for an account to have control of the PLC), a successful attack has the potential to inflict great damage on targets. Threat actors could launch a DoS attack against a device using a vulnerable version of CODESYS to shut down industrial operations or exploit the RCE vulnerabilities to deploy a backdoor to steal sensitive data, tamper with operations, or force a PLC to operate in a dangerous way.
> 
> 


Microsoft privately notified Codesys of the vulnerabilities in September, and the company has since released patches that fix the vulnerabilities. It’s likely that by now, many vendors using the SDK have installed updates. Any who haven’t should make it a priority.


Microsoft said exploiting the vulnerabilities required a deep knowledge of Codesys’ proprietary protocol. It also requires attackers clear a tall hurdle in the form of gaining authentication to a vulnerable device. One way to achieve authentication is to exploit an already patched vulnerability tracked as CVE-2019-9013 in the event a PLC hasn’t yet been patched against it.


While the vulnerabilities are difficult to exploit, threat actors have been able to pull off such attacks in the past. Malware tracked as Triton and Trisis have been used in [at least](https://arstechnica.com/information-technology/2017/12/game-changing-attack-on-critical-infrastructure-site-causes-outage/) [two](https://arstechnica.com/information-technology/2019/04/mysterious-safety-tampering-malware-infects-a-2nd-critical-infrastructure-site/) critical facilities. The malware, [attributed to the Kremlin](https://arstechnica.com/information-technology/2018/10/russia-was-likely-behind-dangerous-critical-infrastructure-attack-report-says/), is designed to disable safety systems that detect and remediate unsafe conditions.


Such attacks are rare, however. Combined with the likelihood that the 15 vulnerabilities are patched in most previously vulnerable production environments, the dire consequences Microsoft is warning of appear unlikely.


The vulnerabilities are tracked as:





|  |  |  |  |
| --- | --- | --- | --- |
| **CVE** | **CODESYS component** | **CVSS score** | **Impact** |
| [CVE-2022-47379](https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2022-47379) | CMPapp | 8.8 | DoS, RCE |
| [CVE-2022-47380](https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2022-47380) | CMPapp | 8.8 |
| [CVE-2022-47381](https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2022-47381) | CMPapp | 8.8 |
| [CVE-2022-47382](https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2022-47382) | CmpTraceMgr | 8.8 |
| [CVE-2022-47383](https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2022-47383) | CmpTraceMgr | 8.8 |
| [CVE-2022-47384](https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2022-47384) | CmpTraceMgr | 8.8 |
| [CVE-2022-47385](https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2022-47385) | CmpAppForce | 8.8 |
| [CVE-2022-47386](https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2022-47386) | CmpTraceMgr | 8.8 |
| [CVE-2022-47387](https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2022-47387) | CmpTraceMgr | 8.8 |
| [CVE-2022-47388](https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2022-47388) | CmpTraceMgr | 8.8 |
| [CVE-2022-47389](https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2022-47389) | CMPTraceMgr | 8.8 |
| [CVE-2022-47390](https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2022-47390) | CMPTraceMgr | 8.8 |
| [CVE-2022-47391](https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2022-47391) | CMPDevice | 7.5 | DoS |
| [CVE-2022-47392](https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2022-47392) | CmpApp/ CmpAppBP/ CmpAppForce | 8.8 |
| [CVE-2022-47393](https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2022-47393) | CmpFiletransfer | 8.8 |





Codesys on Friday issued its [own advisory](https://customers.codesys.com/index.php?eID=dumpFile&t=f&f=17554&token=5444f53b4c90fe37043671a100dffa75305d1825&download=), and Microsoft has made code available [here](https://github.com/microsoft/ics-forensics-tools) that helps organizations identify any vulnerable devices that may still be in use.














## Tags:
***CVE's***: CVE-2022-47386 CVE-2022-47392 CVE-2022-47393 CVE-2022-47379 CVE-2022-47381 CVE-2022-47380 CVE-2022-47385 CVE-2019-9013 CVE-2022-47389 CVE-2022-47391 CVE-2022-47388 CVE-2022-47384 CVE-2022-47387 CVE-2022-47382 CVE-2022-47383 CVE-2022-47390

### Autogenerated tags:
[[codesys]] [[cmptracemgr]] [[microsoft]] [[plc]] [[cmpapp]] [[v3]] [[rce]]
